==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/ka_GE.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "აქტივობა",
    "Personal activity feed for %s" : "პერსონალურ აქტივობათა ლენტი %s -თვის",
    "Your feed URL is invalid" : "სიახლეთა ლენტის URL არასწორია",
    "Your settings have been updated." : "პარამეტრები განახლებულია",
    "Mail" : "ფოსტა",
    "Stream" : "ნაკადი",
    "Activities" : "აქტივობები",
    "Error loading activities" : "აქტივობათა ჩამოტვირთვის დროს მოხდა შეცდომა",
    "No activities" : "აქტივობები არაა",
    "This stream will show events like additions, changes & shares" : "ამ ნაკადში ნაჩვენები იქნება შეტყობინებები ისეთი მოვლენების შესახებ, როგორებიცაა დამატება, ცვლილებები და გაზიარება",
    "There are no events for this filter" : "ამ ფილტრთან შესაბამისი მოვლენები არაა",
    "Activity notification" : "შეტყობინება აქტივობის შესახებ",
    "All Activities" : "ყველა აქტივობა",
    "Activities by you" : "თქვენი აქტივობები",
    "Activities by others" : "სხვათა აქტივობები",
    "\"remote user\"" : "\"მოშორებული მომხმარებელი\"",
    "in %s" : "%s -ში",
    "%s and %s" : "%s და %s",
    ", " : ",",
    "_%s and <strong %s>%n more</strong>_::_%s and <strong %s>%n more</strong>_" : ["%s და <strong %s>%n მეტი</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s და %n მეტი"],
    "Hello %s," : "გამარჯობა, %s,",
    "You are receiving this email because the following things happened at %s" : "გაცნობებთ, რომ %s -ზე",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* და %n მეტი"],
    "Notifications" : "შეტყობინებები",
    "List your own actions in the stream" : "ნაკადზე თქვენი მოქმედებების ჩვენება",
    "Notify about your own actions via email" : "თქვენი მოქმედებების შესახებ ელ.ფოსტით შეტყობინება",
    "You need to set up your email address before you can receive notification emails." : "ელ.ფოსტაზე შეტყობინების მისაღებად საჭიროა მისამართის მითითება",
    "Send emails:" : "წერილების გაგზავნა:",
    "Hourly" : "საათობრივი",
    "Daily" : "ყოველდღიური",
    "Weekly" : "ყოველკვირეული",
    "Activity feed" : "სიახლეთა ლენტი",
    "Enable RSS feed" : "RSS ლენტის გააქტიურება",
    "No activity yet" : "ჯერ-ჯერობით აქტივობები არაა",
    "No more events to load" : "ყველა მოვლენა ჩამოტვირთულია",
    "Files" : "ფაილები",
    "_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_" : ["%s და <strong class=\"has-tooltip\" title=\"%s\">%n მეტი</strong>"]
},
"nplurals=1; plural=0;");

==> owncloud-9.1.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/ka_GE.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "აქტივობა",
    "Activities" : "აქტივობები",
    "Error loading activities" : "აქტივობათა ჩამოტვირთვის დროს მოხდა შეცდომა",
    "No activities" : "აქტივობები არაა",
    ", " : ",",
    "This stream will show events like additions, changes & shares" : "ამ ნაკადში ნაჩვენები იქნება შეტყობინებები ისეთი მოვლენების შესახებ, როგორებიცაა დამატება, ცვლილებები და გაზიარება",
    "There are no events for this filter" : "ამ ფილტრთან შესაბამისი მოვლენები არაა",
    "Today" : "დღეს",
    "Personal activity feed for %s" : "პერსონალურ აქტივობათა ლენტი %s -თვის",
    "Your feed URL is invalid" : "სიახლეთა ლენტის URL არასწორია",
    "Your settings have been updated." : "პარამეტრები განახლებულია",
    "Mail" : "ფოსტა",
    "Stream" : "ნაკადი",
    "\"remote user\"" : "\"მოშორებული მომხმარებელი\"",
    "Activity notification" : "შეტყობინება აქტივობის შესახებ",
    "All Activities" : "ყველა აქტივობა",
    "Activities by you" : "თქვენი აქტივობები",
    "Activities by others" : "სხვათა აქტივობები",
    "%s and %s" : "%s და %s",
    "Hello %s," : "გამარჯობა, %s,",
    "You are receiving this email because the following things happened at %s" : "გაცნობებთ, რომ %s -ზე",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* და %n მეტი"],
    "Notify about your own actions via email" : "თქვენი მოქმედებების შესახებ ელ.ფოსტით შეტყობინება",
    "You need to set up your email address before you can receive notification emails." : "ელ.ფოსტაზე შეტყობინების მისაღებად საჭიროა მისამართის მითითება",
    "Send emails:" : "წერილების გაგზავნა:",
    "Hourly" : "საათობრივი",
    "Daily" : "ყოველდღიური",
    "Weekly" : "ყოველკვირეული",
    "Activity feed" : "სიახლეთა ლენტი",
    "Enable RSS feed" : "RSS ლენტის გააქტიურება",
    "No activity yet" : "ჯერ-ჯერობით აქტივობები არაა",
    "No more events to load" : "ყველა მოვლენა ჩამოტვირთულია",
    "Files" : "ფაილები"
},
"nplurals=1; plural=0;");
